module Mybot
	class Command
		include Fmt

		attr_accessor :channel, :exit

		def initialize
			@out = @stdout = @stderr = ""
			@handlers = {}
			@time = Time.now
			@exit = -1
		end

		def on(s, &block)
			@handlers[s] = block
		end

		def handle_stdout(data)
			@out = data
			@stdout += data
			print_stdout data
			run_handlers
		end

		def handle_stderr(data)
			@out = data
			@stderr += data
			print_stderr data
			run_handlers
		end

		def handle_close
			@time = Time.now - @time
			print_cmd! "time", @time, :blue, :bold
			print_cmd! "exit", @exit, :blue, :bold

			unless @exit == 0
				print_cmd! "error", "invalid exit status", :red, :bold
				print_stdout @stdout, true
				print_stderr @stderr, true
				abort
			end
		end

		def write(data)
			print_cmd! "write", data, :blue, :bold
			@channel.send_data "#{data}\n"
		end

		def write!(data)
			print_cmd! "write", asterisks(data), :blue, :bold
			@channel.send_data "#{data}\n"
		end

		def result
			{ 
				:stdout => filter(@stdout),
				:stderr => filter(@stderr),
				:exit => @exit,
				:time => @time
			}
		end

	private

		def run_handlers
			@handlers.each do |s, block|
				if @out.include? s
					puts if @out[-3..-1] == "\r\n" && $MYBOT_SHOW_OUTPUT
					print_cmd! "handle", s, :blue, :bold
					block.call
				end
			end
		end

		def filter(data)
      data.gsub(/\[sudo\]\ password\ for\ [a-zA-Z0-9_].+\:/, "")
    end
	end
end