require "colored"

module Mybot
  module Fmt
    WIDTH = 10

    def print_cmd(type, msg, *colors)
      if $MYBOT_SHOW_CMD
        $stdout.print "#{spaces(type)}#{colored(type, *colors)} #{msg.to_s}"
      end
    end

    def print_cmd!(type, msg, *colors)
      print_cmd type, "#{msg}\n", *colors
    end

    def print_stdout(data, force = false)
      $stdout.print colored(data, :green) if $MYBOT_SHOW_OUTPUT || force
    end

    def print_stderr(data, force = false)
      $stdout.print colored(data, :red) if $MYBOT_SHOW_OUTPUT || force
    end

    def print_progress(n)
      if $MYBOT_SHOW_CMD
        cmd = colored "progress", :blue, :bold
        $stdout.print "\r#{spaces('progress')}#{cmd} #{n}%"
        puts if n == 100
      end
    end
    
    def colored(str, *colors)
      if $MYBOT_USE_COLORS
        colors.each do |c|
          str = str.send(c)
        end
        str
      else
        str
      end
    end

    def spaces(str)
      " " * (WIDTH - str.size)
    end

    def asterisks(str)
      "*" * str.size
    end
  end
end